==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Surveys/language/lang-finnish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","Nimesi");
define("_OK","Ok!");
define("_COMMENT","kommentti"); 
 
define("_CONFIGURE","Muokkaa");
define("_LOGINCREATE","Kirjaudu/Rekisteridy");
define("_THRESHOLD","Pisteet");
define("_NOCOMMENTS","Ei kommentteja");
define("_NESTED","Sisennetty nkym");
define("_FLAT","Allekkainen nkym");
define("_THREAD","Puu");
define("_OLDEST","Vanhimmat eka");
define("_NEWEST","Uusimmat eka");
define("_HIGHEST","Parhaat pisteet eka");
define("_COMMENTSWARNING","Kommentit ovat kyttjien omia - me emme ole niist missn vastuussa.");
define("_SCORE","Pisteet:");
define("_USERINFO","Kyttjn tiedot");
define("_READREST","Lue kommentista loputkin...");
define("_REPLY","Vastaa");
define("_REPLYMAIN","Lhet kommentti");
define("_NOSUBJECT","Ei aihetta");
define("_NOANONCOMMENTS","Anonyymi ei saa antaa kommentteja...ole hyv ja <a href=\"user.php\">rekisteridy</a>");
define("_PARENT","rinnakkainen");
define("_ROOT","Root");
define("_UCOMMENT","Kommenttia");
define("_ALLOWEDHTML","HTML sallittu:");
define("_POSTANON","Kirjoita anonyymisti");
define("_EXTRANS","Lis html tagit tekstiin");
define("_HTMLFORMATED","HTML formatoituna");
define("_PLAINTEXT","Pelkkn tekstin");
define("_ONN","on...");
define("_SUBJECT","Aihe");
define("_SURVEYCOM","Kommentoi kysely");
define("_SURVEYCOMPRE","Esikatsele");
define("_NOTRIGHT","Joku nyt ei ole vaan oikein - ota yhteytt yllpitoon jos tilanne vain jatkuu");
define("_DIRECTCOM","Direct Survey Comment...");
define("_SENDAMSG","Lhet viesti");
define("_PASTSURVEYS","Menneet kyselyt");



define("_LVOTES","nt");
define("_TOTALVOTES","ni :");
define("_VOTING","nestykset");
define("_OTHERPOLLS","Muut kyselyt");
define("_CURRENTSURVEY","Nykyinen selvitys");
define("_CURRENTPOLLRESULTS","Nykyisen kyselyn tulokset");
define("_PREVIEW","Esikatsele");
define("_REFRESH","Pivit");
define("_SURVEYS","Kyselyt");
define("_ATTACHEDTOARTICLE","- Attached to article:");
define("_SURVEYSATTACHED","Surveys Attached to Articles");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Surveys/language/lang-finnish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","Nimesi");
define("_OK","Ok!");
define("_COMMENT","kommentti"); 
 
define("_CONFIGURE","Muokkaa");
define("_LOGINCREATE","Kirjaudu/Rekisteridy");
define("_THRESHOLD","Pisteet");
define("_NOCOMMENTS","Ei kommentteja");
define("_NESTED","Sisennetty nkym");
define("_FLAT","Allekkainen nkym");
define("_THREAD","Puu");
define("_OLDEST","Vanhimmat eka");
define("_NEWEST","Uusimmat eka");
define("_HIGHEST","Parhaat pisteet eka");
define("_COMMENTSWARNING","Kommentit ovat kyttjien omia - me emme ole niist missn vastuussa.");
define("_SCORE","Pisteet:");
define("_USERINFO","Kyttjn tiedot");
define("_READREST","Lue kommentista loputkin...");
define("_REPLY","Vastaa");
define("_REPLYMAIN","Lhet kommentti");
define("_NOSUBJECT","Ei aihetta");
define("_NOANONCOMMENTS","Anonyymi ei saa antaa kommentteja...ole hyv ja <a href=\"user.php\">rekisteridy</a>");
define("_PARENT","rinnakkainen");
define("_ROOT","Root");
define("_UCOMMENT","Kommenttia");
define("_ALLOWEDHTML","HTML sallittu:");
define("_POSTANON","Kirjoita anonyymisti");
define("_EXTRANS","Lis html tagit tekstiin");
define("_HTMLFORMATED","HTML formatoituna");
define("_PLAINTEXT","Pelkkn tekstin");
define("_ONN","on...");
define("_SUBJECT","Aihe");
define("_SURVEYCOM","Kommentoi kysely");
define("_SURVEYCOMPRE","Esikatsele");
define("_NOTRIGHT","Joku nyt ei ole vaan oikein - ota yhteytt yllpitoon jos tilanne vain jatkuu");
define("_DIRECTCOM","Direct Survey Comment...");
define("_SENDAMSG","Lhet viesti");
define("_PASTSURVEYS","Menneet kyselyt");



define("_LVOTES","nt");
define("_TOTALVOTES","ni :");
define("_VOTING","nestykset");
define("_OTHERPOLLS","Muut kyselyt");
define("_CURRENTSURVEY","Nykyinen selvitys");
define("_CURRENTPOLLRESULTS","Nykyisen kyselyn tulokset");
define("_PREVIEW","Esikatsele");
define("_REFRESH","Pivit");
define("_SURVEYS","Kyselyt");
define("_ATTACHEDTOARTICLE","- Attached to article:");
define("_SURVEYSATTACHED","Surveys Attached to Articles");

?>
